package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.SysArea;

/**
 * 区域-省市区县Service接口
 *
 * @author ruoyi
 * @date 2025-09-29
 */
public interface ISysAreaService
{
    /**
     * 查询区域-省市区县
     *
     * @param areaId 区域-省市区县主键
     * @return 区域-省市区县
     */
    public SysArea selectSysAreaByAreaId(Long areaId);

    /**
     * 查询区域-省市区县列表
     *
     * @param sysArea 区域-省市区县
     * @return 区域-省市区县集合
     */
    public List<SysArea> selectSysAreaList(SysArea sysArea);
    public List<SysArea> selectSysAreaListByIds(List<Long> ids);
    public List<SysArea> listTree(SysArea criteria);
    /**
     * 新增区域-省市区县
     *
     * @param sysArea 区域-省市区县
     * @return 结果
     */
    public int insertSysArea(SysArea sysArea);

    /**
     * 修改区域-省市区县
     *
     * @param sysArea 区域-省市区县
     * @return 结果
     */
    public int updateSysArea(SysArea sysArea);

    /**
     * 批量删除区域-省市区县
     *
     * @param areaIds 需要删除的区域-省市区县主键集合
     * @return 结果
     */
    public int deleteSysAreaByAreaIds(Long[] areaIds);

    /**
     * 删除区域-省市区县信息
     *
     * @param areaId 区域-省市区县主键
     * @return 结果
     */
    public int deleteSysAreaByAreaId(Long areaId);
}
